# -*- coding: utf-8 -*-
"""AlphaGradient's algorithm library, containing vetted and high
quality financial algorithms to be used freely.

Todo:
    * NA
"""
from ._lib import IndexHold, ThetaGang, TemplateAlgo

__all__ = ["IndexHold", "ThetaGang", "TemplateAlgo"]
